/* C++ code produced by gperf version 3.0.4 */
/* Command-line: gperf  */
/* Computed positions: -k'1,6-7,9,11,$' */

#if !((' ' == 32) && ('!' == 33) && ('"' == 34) && ('#' == 35) \
      && ('%' == 37) && ('&' == 38) && ('\'' == 39) && ('(' == 40) \
      && (')' == 41) && ('*' == 42) && ('+' == 43) && (',' == 44) \
      && ('-' == 45) && ('.' == 46) && ('/' == 47) && ('0' == 48) \
      && ('1' == 49) && ('2' == 50) && ('3' == 51) && ('4' == 52) \
      && ('5' == 53) && ('6' == 54) && ('7' == 55) && ('8' == 56) \
      && ('9' == 57) && (':' == 58) && (';' == 59) && ('<' == 60) \
      && ('=' == 61) && ('>' == 62) && ('?' == 63) && ('A' == 65) \
      && ('B' == 66) && ('C' == 67) && ('D' == 68) && ('E' == 69) \
      && ('F' == 70) && ('G' == 71) && ('H' == 72) && ('I' == 73) \
      && ('J' == 74) && ('K' == 75) && ('L' == 76) && ('M' == 77) \
      && ('N' == 78) && ('O' == 79) && ('P' == 80) && ('Q' == 81) \
      && ('R' == 82) && ('S' == 83) && ('T' == 84) && ('U' == 85) \
      && ('V' == 86) && ('W' == 87) && ('X' == 88) && ('Y' == 89) \
      && ('Z' == 90) && ('[' == 91) && ('\\' == 92) && (']' == 93) \
      && ('^' == 94) && ('_' == 95) && ('a' == 97) && ('b' == 98) \
      && ('c' == 99) && ('d' == 100) && ('e' == 101) && ('f' == 102) \
      && ('g' == 103) && ('h' == 104) && ('i' == 105) && ('j' == 106) \
      && ('k' == 107) && ('l' == 108) && ('m' == 109) && ('n' == 110) \
      && ('o' == 111) && ('p' == 112) && ('q' == 113) && ('r' == 114) \
      && ('s' == 115) && ('t' == 116) && ('u' == 117) && ('v' == 118) \
      && ('w' == 119) && ('x' == 120) && ('y' == 121) && ('z' == 122) \
      && ('{' == 123) && ('|' == 124) && ('}' == 125) && ('~' == 126))
/* The character set is not based on ISO-646.  */
#error "gperf generated tables don't work with this execution character set. Please report a bug to <bug-gnu-gperf@gnu.org>."
#endif


#include <dballe/core/defs.h>
#include <dballe/msg/vars.h>
#include <string.h>

namespace dballe {
struct msgvardef { const char* name; int var; };

#define TOTAL_KEYWORDS 92
#define MIN_WORD_LENGTH 3
#define MAX_WORD_LENGTH 22
#define MIN_HASH_VALUE 5
#define MAX_HASH_VALUE 287
/* maximum key range = 283, duplicates = 0 */

class MsgVarLookup
{
private:
  static inline unsigned int hash (const char *str, unsigned int len);
public:
  static struct msgvardef *find (const char *str, unsigned int len);
};

inline unsigned int
MsgVarLookup::hash (register const char *str, register unsigned int len)
{
  static unsigned short asso_values[] =
    {
      288, 288, 288, 288, 288, 288, 288, 288, 288, 288,
      288, 288, 288, 288, 288, 288, 288, 288, 288, 288,
      288, 288, 288, 288, 288, 288, 288, 288, 288, 288,
      288, 288, 288, 288, 288, 288, 288, 288, 288, 288,
      288, 288, 288, 288, 288, 288, 288, 288, 288,  75,
       60,  40, 125, 288,  20, 288, 288, 288, 288, 288,
      288, 288, 288, 288, 288, 288, 288, 288, 288, 288,
      288, 288, 288, 288, 288, 288, 288, 288, 288, 288,
      288, 288, 288, 288, 288, 288, 288, 288, 288, 288,
      288, 288, 288, 288, 288,   5, 288,  15,   0,  10,
       25,   5,  55,   5,   5,  60, 288,   5,  45,  15,
        0,  85,   0,   0,   5,   0,   0,  40,   0,  40,
      288, 115, 288, 288, 288, 288, 288, 288, 288, 288,
      288, 288, 288, 288, 288, 288, 288, 288, 288, 288,
      288, 288, 288, 288, 288, 288, 288, 288, 288, 288,
      288, 288, 288, 288, 288, 288, 288, 288, 288, 288,
      288, 288, 288, 288, 288, 288, 288, 288, 288, 288,
      288, 288, 288, 288, 288, 288, 288, 288, 288, 288,
      288, 288, 288, 288, 288, 288, 288, 288, 288, 288,
      288, 288, 288, 288, 288, 288, 288, 288, 288, 288,
      288, 288, 288, 288, 288, 288, 288, 288, 288, 288,
      288, 288, 288, 288, 288, 288, 288, 288, 288, 288,
      288, 288, 288, 288, 288, 288, 288, 288, 288, 288,
      288, 288, 288, 288, 288, 288, 288, 288, 288, 288,
      288, 288, 288, 288, 288, 288, 288, 288, 288, 288,
      288, 288, 288, 288, 288, 288
    };
  register int hval = len;

  switch (hval)
    {
      default:
        hval += asso_values[(unsigned char)str[10]];
      /*FALLTHROUGH*/
      case 10:
      case 9:
        hval += asso_values[(unsigned char)str[8]];
      /*FALLTHROUGH*/
      case 8:
      case 7:
        hval += asso_values[(unsigned char)str[6]];
      /*FALLTHROUGH*/
      case 6:
        hval += asso_values[(unsigned char)str[5]];
      /*FALLTHROUGH*/
      case 5:
      case 4:
      case 3:
      case 2:
      case 1:
        hval += asso_values[(unsigned char)str[0]];
        break;
    }
  return hval + asso_values[(unsigned char)str[len - 1]];
}

static struct msgvardef wordlist[] =
  {
    {""}, {""}, {""}, {""}, {""},
    {"press", DBA_MSG_PRESS},
    {"navsys", DBA_MSG_NAVSYS},
    {""},
    {"qnh", DBA_MSG_QNH},
    {""},
    {"block", DBA_MSG_BLOCK},
    {""}, {""}, {""},
    {"hour", DBA_MSG_HOUR},
    {"poll_ttype", DBA_MSG_POLL_TTYPE},
    {"st_dir", DBA_MSG_ST_DIR},
    {"st_type", DBA_MSG_ST_TYPE},
    {""}, {""},
    {"sonde_type", DBA_MSG_SONDE_TYPE},
    {""},
    {"cloud_n", DBA_MSG_CLOUD_N},
    {""},
    {"height_station", DBA_MSG_HEIGHT_STATION},
    {"month", DBA_MSG_MONTH},
    {""}, {""},
    {"cloud_nh", DBA_MSG_CLOUD_NH},
    {"temp_precision", DBA_MSG_TEMP_PRECISION},
    {"poll_atype", DBA_MSG_POLL_ATYPE},
    {"minute", DBA_MSG_MINUTE},
    {"st_name", DBA_MSG_ST_NAME},
    {"cloud_hh", DBA_MSG_CLOUD_HH},
    {""}, {""}, {""}, {""},
    {"cloud_ch", DBA_MSG_CLOUD_CH},
    {"height_release", DBA_MSG_HEIGHT_RELEASE},
    {"press_tend", DBA_MSG_PRESS_TEND},
    {"sonde_correction", DBA_MSG_SONDE_CORRECTION},
    {""},
    {"st_speed", DBA_MSG_ST_SPEED},
    {"sonde_tracking", DBA_MSG_SONDE_TRACKING},
    {""}, {""}, {""},
    {"cloud_cm", DBA_MSG_CLOUD_CM},
    {""},
    {"poll_scode", DBA_MSG_POLL_SCODE},
    {"height_anem", DBA_MSG_HEIGHT_ANEM},
    {""},
    {"pres_wtr", DBA_MSG_PRES_WTR},
    {""}, {""},
    {"second", DBA_MSG_SECOND},
    {""},
    {"press_3h", DBA_MSG_PRESS_3H},
    {"tot_prec6", DBA_MSG_TOT_PREC6},
    {""}, {""}, {""},
    {"cloud_n3", DBA_MSG_CLOUD_N3},
    {""},
    {"ident", DBA_MSG_IDENT},
    {""}, {""},
    {"cloud_h3", DBA_MSG_CLOUD_H3},
    {""},
    {"water_temp", DBA_MSG_WATER_TEMP},
    {""}, {""},
    {"cloud_c3", DBA_MSG_CLOUD_C3},
    {""}, {""}, {""},
    {"timesig", DBA_MSG_TIMESIG},
    {"cloud_cl", DBA_MSG_CLOUD_CL},
    {"metar_wtr", DBA_MSG_METAR_WTR},
    {"wind_speed", DBA_MSG_WIND_SPEED},
    {"latlon_spec", DBA_MSG_LATLON_SPEC},
    {"flight_phase", DBA_MSG_FLIGHT_PHASE},
    {"cloud_n2", DBA_MSG_CLOUD_N2},
    {"press_24h", DBA_MSG_PRESS_24H},
    {"ex_cw_wind", DBA_MSG_EX_CW_WIND},
    {""}, {""},
    {"cloud_h2", DBA_MSG_CLOUD_H2},
    {""}, {""}, {""},
    {"station", DBA_MSG_STATION},
    {"cloud_c2", DBA_MSG_CLOUD_C2},
    {""},
    {"poll_lcode", DBA_MSG_POLL_LCODE},
    {""},
    {"temp_2m", DBA_MSG_TEMP_2M},
    {"cloud_n1", DBA_MSG_CLOUD_N1},
    {"tot_prec3", DBA_MSG_TOT_PREC3},
    {""}, {""}, {""},
    {"cloud_h1", DBA_MSG_CLOUD_H1},
    {"longitude", DBA_MSG_LONGITUDE},
    {"meas_equip_type", DBA_MSG_MEAS_EQUIP_TYPE},
    {"wet_temp_2m", DBA_MSG_WET_TEMP_2M},
    {""},
    {"cloud_c1", DBA_MSG_CLOUD_C1},
    {"wind_inst", DBA_MSG_WIND_INST},
    {""},
    {"poll_source", DBA_MSG_POLL_SOURCE},
    {""},
    {"poll_gemscode", DBA_MSG_POLL_GEMSCODE},
    {""}, {""}, {""}, {""},
    {"rep_memo", DBA_MSG_REP_MEMO},
    {"press_msl", DBA_MSG_PRESS_MSL},
    {""}, {""},
    {"wind_gust_max_dir", DBA_MSG_WIND_GUST_MAX_DIR},
    {"latitude", DBA_MSG_LATITUDE},
    {"year", DBA_MSG_YEAR},
    {""}, {""}, {""}, {""}, {""}, {""},
    {"dewpoint_2m", DBA_MSG_DEWPOINT_2M},
    {"state_ground", DBA_MSG_STATE_GROUND},
    {"tot_snow", DBA_MSG_TOT_SNOW},
    {""}, {""}, {""},
    {"past_wtr2_6h", DBA_MSG_PAST_WTR2_6H},
    {"wind_dir", DBA_MSG_WIND_DIR},
    {""}, {""}, {""},
    {"sonde_method", DBA_MSG_SONDE_METHOD},
    {"day", DBA_MSG_DAY},
    {"wind_gust_max_speed", DBA_MSG_WIND_GUST_MAX_SPEED},
    {""}, {""}, {""},
    {"cloud_n4", DBA_MSG_CLOUD_N4},
    {""}, {""}, {""},
    {"past_wtr1_6h", DBA_MSG_PAST_WTR1_6H},
    {"cloud_h4", DBA_MSG_CLOUD_H4},
    {""},
    {"tot_prec12", DBA_MSG_TOT_PREC12},
    {""},
    {"past_wtr2_3h", DBA_MSG_PAST_WTR2_3H},
    {"cloud_c4", DBA_MSG_CLOUD_C4},
    {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
    {"flight_reg_no", DBA_MSG_FLIGHT_REG_NO},
    {"tot_prec1", DBA_MSG_TOT_PREC1},
    {""},
    {"ex_ccw_wind", DBA_MSG_EX_CCW_WIND},
    {"past_wtr1_3h", DBA_MSG_PAST_WTR1_3H},
    {""}, {""},
    {"data_relay", DBA_MSG_DATA_RELAY},
    {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
    {""}, {""}, {""},
    {"humidity", DBA_MSG_HUMIDITY},
    {""}, {""},
    {"isobaric_surface", DBA_MSG_ISOBARIC_SURFACE},
    {"st_name_icao", DBA_MSG_ST_NAME_ICAO},
    {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
    {""}, {""}, {""},
    {"tot_prec24", DBA_MSG_TOT_PREC24},
    {"height_baro", DBA_MSG_HEIGHT_BARO},
    {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
    {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
    {""}, {""}, {""}, {""}, {""},
    {"visibility", DBA_MSG_VISIBILITY},
    {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
    {""}, {""}, {""}, {""}, {""}, {""},
    {"flight_roll", DBA_MSG_FLIGHT_ROLL},
    {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
    {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
    {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
    {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""}, {""},
    {""}, {""}, {""}, {""},
    {"station_height_quality", DBA_MSG_STATION_HEIGHT_QUALITY}
  };

struct msgvardef *
MsgVarLookup::find (register const char *str, register unsigned int len)
{
  if (len <= MAX_WORD_LENGTH && len >= MIN_WORD_LENGTH)
    {
      register int key = hash (str, len);

      if (key <= MAX_HASH_VALUE && key >= 0)
        {
          register const char *s = wordlist[key].name;

          if (*str == *s && !strncmp (str + 1, s + 1, len - 1) && s[len] == '\0')
            return &wordlist[key];
        }
    }
  return 0;
}


int resolve_var(const char* name)
{
    struct msgvardef* res = MsgVarLookup::find(name, strlen(name));
	if (res == NULL)
		return -1;
	else
		return res->var;
}

int resolve_var_substring(const char* name, int len)
{
    struct msgvardef* res = MsgVarLookup::find(name, len);
	if (res == NULL)
		return -1;
	else
		return res->var;
}


struct MsgVarShortcut shortcutTable[] = {
 { WR_VAR(0, 1, 1), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
 { WR_VAR(0, 1, 2), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
 { WR_VAR(0, 1, 8), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
 { WR_VAR(0, 1, 11), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
 { WR_VAR(0, 1, 19), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
 { WR_VAR(0, 1, 63), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
 { WR_VAR(0, 1, 194), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
 { WR_VAR(0, 1, 212), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
 { WR_VAR(0, 1, 213), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
 { WR_VAR(0, 1, 214), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
 { WR_VAR(0, 1, 215), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
 { WR_VAR(0, 1, 216), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
 { WR_VAR(0, 1, 217), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
 { WR_VAR(0, 2, 1), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
 { WR_VAR(0, 2, 2), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
 { WR_VAR(0, 2, 5), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
 { WR_VAR(0, 2, 61), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
 { WR_VAR(0, 2, 62), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
 { WR_VAR(0, 2, 63), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
 { WR_VAR(0, 2, 70), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
 { WR_VAR(0, 4, 1), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
 { WR_VAR(0, 4, 2), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
 { WR_VAR(0, 4, 3), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
 { WR_VAR(0, 4, 4), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
 { WR_VAR(0, 4, 5), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
 { WR_VAR(0, 4, 6), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
 { WR_VAR(0, 5, 1), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
 { WR_VAR(0, 6, 1), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
 { WR_VAR(0, 7, 4), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
 { WR_VAR(0, 7, 7), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
 { WR_VAR(0, 7, 30), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
 { WR_VAR(0, 7, 31), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
 { WR_VAR(0, 8, 4), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
 { WR_VAR(0, 8, 21), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
 { WR_VAR(0, 33, 24), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
 { WR_VAR(0, 20, 10), 256, MISSING_INT, MISSING_INT, MISSING_INT, 254, 0, 0 },
 { WR_VAR(0, 20, 11), 256, MISSING_INT, 259, 4, 254, 0, 0 },
 { WR_VAR(0, 20, 12), 256, MISSING_INT, 259, 4, 254, 0, 0 },
 { WR_VAR(0, 20, 13), 256, MISSING_INT, 259, 4, 254, 0, 0 },
 { WR_VAR(0, 20, 11), 256, MISSING_INT, 259, 3, 254, 0, 0 },
 { WR_VAR(0, 20, 12), 256, MISSING_INT, 259, 3, 254, 0, 0 },
 { WR_VAR(0, 20, 13), 256, MISSING_INT, 259, 3, 254, 0, 0 },
 { WR_VAR(0, 20, 11), 256, MISSING_INT, 259, 2, 254, 0, 0 },
 { WR_VAR(0, 20, 12), 256, MISSING_INT, 259, 2, 254, 0, 0 },
 { WR_VAR(0, 20, 13), 256, MISSING_INT, 259, 2, 254, 0, 0 },
 { WR_VAR(0, 20, 11), 256, MISSING_INT, 259, 1, 254, 0, 0 },
 { WR_VAR(0, 20, 12), 256, MISSING_INT, 259, 1, 254, 0, 0 },
 { WR_VAR(0, 20, 13), 256, MISSING_INT, 259, 1, 254, 0, 0 },
 { WR_VAR(0, 20, 12), 256, MISSING_INT, 258, 3, 254, 0, 0 },
 { WR_VAR(0, 20, 12), 256, MISSING_INT, 258, 2, 254, 0, 0 },
 { WR_VAR(0, 20, 12), 256, MISSING_INT, 258, 1, 254, 0, 0 },
 { WR_VAR(0, 20, 11), 256, MISSING_INT, 258, 0, 254, 0, 0 },
 { WR_VAR(0, 20, 13), 256, MISSING_INT, 258, 0, 254, 0, 0 },
 { WR_VAR(0, 11, 1), 103, 10000, MISSING_INT, MISSING_INT, 254, 0, 0 },
 { WR_VAR(0, 11, 2), 103, 10000, MISSING_INT, MISSING_INT, 254, 0, 0 },
 { WR_VAR(0, 11, 16), 103, 10000, MISSING_INT, MISSING_INT, 254, 0, 0 },
 { WR_VAR(0, 11, 17), 103, 10000, MISSING_INT, MISSING_INT, 254, 0, 0 },
 { WR_VAR(0, 11, 41), 103, 10000, MISSING_INT, MISSING_INT, 254, 0, 0 },
 { WR_VAR(0, 11, 43), 103, 10000, MISSING_INT, MISSING_INT, 254, 0, 0 },
 { WR_VAR(0, 10, 52), 103, 2000, MISSING_INT, MISSING_INT, 254, 0, 0 },
 { WR_VAR(0, 12, 101), 103, 2000, MISSING_INT, MISSING_INT, 254, 0, 0 },
 { WR_VAR(0, 12, 102), 103, 2000, MISSING_INT, MISSING_INT, 254, 0, 0 },
 { WR_VAR(0, 12, 103), 103, 2000, MISSING_INT, MISSING_INT, 254, 0, 0 },
 { WR_VAR(0, 13, 3), 103, 2000, MISSING_INT, MISSING_INT, 254, 0, 0 },
 { WR_VAR(0, 10, 51), 101, MISSING_INT, MISSING_INT, MISSING_INT, 254, 0, 0 },
 { WR_VAR(0, 1, 12), 1, MISSING_INT, MISSING_INT, MISSING_INT, 254, 0, 0 },
 { WR_VAR(0, 1, 13), 1, MISSING_INT, MISSING_INT, MISSING_INT, 254, 0, 0 },
 { WR_VAR(0, 2, 3), 1, MISSING_INT, MISSING_INT, MISSING_INT, 254, 0, 0 },
 { WR_VAR(0, 2, 11), 1, MISSING_INT, MISSING_INT, MISSING_INT, 254, 0, 0 },
 { WR_VAR(0, 2, 12), 1, MISSING_INT, MISSING_INT, MISSING_INT, 254, 0, 0 },
 { WR_VAR(0, 2, 13), 1, MISSING_INT, MISSING_INT, MISSING_INT, 254, 0, 0 },
 { WR_VAR(0, 2, 14), 1, MISSING_INT, MISSING_INT, MISSING_INT, 254, 0, 0 },
 { WR_VAR(0, 10, 4), 1, MISSING_INT, MISSING_INT, MISSING_INT, 254, 0, 0 },
 { WR_VAR(0, 10, 197), 1, MISSING_INT, MISSING_INT, MISSING_INT, 254, 0, 0 },
 { WR_VAR(0, 13, 13), 1, MISSING_INT, MISSING_INT, MISSING_INT, 254, 0, 0 },
 { WR_VAR(0, 20, 1), 1, MISSING_INT, MISSING_INT, MISSING_INT, 254, 0, 0 },
 { WR_VAR(0, 20, 3), 1, MISSING_INT, MISSING_INT, MISSING_INT, 254, 0, 0 },
 { WR_VAR(0, 20, 9), 1, MISSING_INT, MISSING_INT, MISSING_INT, 254, 0, 0 },
 { WR_VAR(0, 20, 62), 1, MISSING_INT, MISSING_INT, MISSING_INT, 254, 0, 0 },
 { WR_VAR(0, 22, 43), 1, MISSING_INT, MISSING_INT, MISSING_INT, 254, 0, 0 },
 { WR_VAR(0, 20, 4), 1, MISSING_INT, MISSING_INT, MISSING_INT, 205, 0, 21600 },
 { WR_VAR(0, 20, 5), 1, MISSING_INT, MISSING_INT, MISSING_INT, 205, 0, 21600 },
 { WR_VAR(0, 10, 63), 1, MISSING_INT, MISSING_INT, MISSING_INT, 205, 0, 10800 },
 { WR_VAR(0, 20, 4), 1, MISSING_INT, MISSING_INT, MISSING_INT, 205, 0, 10800 },
 { WR_VAR(0, 20, 5), 1, MISSING_INT, MISSING_INT, MISSING_INT, 205, 0, 10800 },
 { WR_VAR(0, 10, 60), 1, MISSING_INT, MISSING_INT, MISSING_INT, 4, 0, 86400 },
 { WR_VAR(0, 10, 60), 1, MISSING_INT, MISSING_INT, MISSING_INT, 4, 0, 10800 },
 { WR_VAR(0, 13, 11), 1, MISSING_INT, MISSING_INT, MISSING_INT, 1, 0, 86400 },
 { WR_VAR(0, 13, 11), 1, MISSING_INT, MISSING_INT, MISSING_INT, 1, 0, 43200 },
 { WR_VAR(0, 13, 11), 1, MISSING_INT, MISSING_INT, MISSING_INT, 1, 0, 21600 },
 { WR_VAR(0, 13, 11), 1, MISSING_INT, MISSING_INT, MISSING_INT, 1, 0, 10800 },
 { WR_VAR(0, 13, 11), 1, MISSING_INT, MISSING_INT, MISSING_INT, 1, 0, 3600 },
};
} // namespace dballe
